<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:txc="http://www.transxchange.org.uk/" xmlns:apd="http://www.govtalk.gov.uk/people/AddressAndPersonalDetails" exclude-result-prefixes="apd txc">
	<xsl:output method="xml" doctype-public="-//OASIS//DTD DocBook XML V4.2//EN" doctype-system="http://www.oasis-open.org/docbook/xml/4.2/docbookx.dtd" indent="yes"/>
	<xsl:strip-space elements="*"/>
	<!-- ***************************** Parameters ********************************** -->
	<xsl:param name="documentBaseDirectory"/>
	<xsl:param name="validationResultsUrl"/>
	<!-- ***************************** Summary page ********************************** -->
	<xsl:template match="txc:TransXChange">
		<xsl:apply-templates select="." mode="documentSummary"/>
		<xsl:apply-templates select="txc:Operators"/>
		<xsl:apply-templates select="txc:Services"/>
		<xsl:apply-templates select="txc:Registrations"/>
		<section>
			<title>Routes</title>
			<xsl:apply-templates select="txc:StopPoints"/>
			<xsl:apply-templates select="txc:Routes"/>
			<xsl:apply-templates select="txc:Services/txc:Service/txc:FlexibleService"/>
			<xsl:if test="txc:Services/txc:Service/txc:SchematicMap">
				<section>
					<title>Maps</title>
					<xsl:apply-templates select="txc:Services/txc:Service/txc:SchematicMap"/>
				</section>
			</xsl:if>
		</section>
		<xsl:if test="$validationResultsUrl">
			<xsl:apply-templates select="document($validationResultsUrl)" mode="raw-docbook"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="txc:TransXChange" mode="documentSummary">
		<section>
			<title>Document Summary</title>
			<xsl:call-template name="standardAttributes">
				<xsl:with-param name="parentElement" select="."/>
			</xsl:call-template>
			<informaltable>
				<tgroup cols="2">
					<colspec colwidth="1*"/>
					<colspec colwidth="2*"/>
					<tbody>
						<row>
							<entry>File Name</entry>
							<entry>
								<emphasis role="bold">
									<xsl:value-of select="@FileName"/>
								</emphasis>
							</entry>
						</row>
						<row>
							<entry>Schema Version</entry>
							<entry>
								<emphasis role="bold">
									<xsl:value-of select="@SchemaVersion"/>
								</emphasis>
							</entry>
						</row>
						<xsl:if test="@xml:lang!='en'">
							<row>
								<entry>Language</entry>
								<entry>
									<emphasis role="bold">
										<xsl:choose>
											<xsl:when test="@xml:lang='en'">English</xsl:when>
											<xsl:when test="@xml:lang='cy'">Welsh</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="@xml:lang"/>
											</xsl:otherwise>
										</xsl:choose>
									</emphasis>
								</entry>
							</row>
						</xsl:if>
					</tbody>
				</tgroup>
			</informaltable>
			<para>The TransXChange document contains the following entities:</para>
			<itemizedlist>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:Operators/txc:Operator) + count(txc:Operators/txc:LicensedOperator)"/>
					<xsl:with-param name="singular" select="'Operator'"/>
					<xsl:with-param name="plural" select="'Operators'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:ServicedOrganisations/txc:ServicedOrganisation)"/>
					<xsl:with-param name="singular" select="'Serviced Organisation'"/>
					<xsl:with-param name="plural" select="'Serviced Organisations'"/>
					<xsl:with-param name="omitIfZero" select="true()"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:Services/txc:Service)"/>
					<xsl:with-param name="singular" select="'Service'"/>
					<xsl:with-param name="plural" select="'Services'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:Registrations/txc:Registration)"/>
					<xsl:with-param name="singular" select="'Registration'"/>
					<xsl:with-param name="plural" select="'Registrations'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:StopPoints/txc:StopPoint)"/>
					<xsl:with-param name="singular" select="'Stop Point defined in this document'"/>
					<xsl:with-param name="plural" select="'Stop Points defined in this document'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:StopPoints/txc:AnnotatedStopPointRef)"/>
					<xsl:with-param name="singular" select="'Reference to an existing Stop Point'"/>
					<xsl:with-param name="plural" select="'References to existing Stop Points'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:StopAreas/txc:StopArea)"/>
					<xsl:with-param name="singular" select="'Stop Area defined in this document'"/>
					<xsl:with-param name="plural" select="'Stop Areas defined in this document'"/>
					<xsl:with-param name="omitIfZero" select="true()"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:Routes/txc:Route)"/>
					<xsl:with-param name="singular" select="'Route'"/>
					<xsl:with-param name="plural" select="'Routes'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:Services/txc:Service/txc:StandardService/txc:JourneyPattern)"/>
					<xsl:with-param name="singular" select="'Journey Pattern'"/>
					<xsl:with-param name="plural" select="'Journey Patterns'"/>
				</xsl:call-template>
				<xsl:call-template name="itemCountListItem">
					<xsl:with-param name="count" select="count(txc:VehicleJourneys/txc:VehicleJourney)"/>
					<xsl:with-param name="singular" select="'Vehicle Journey'"/>
					<xsl:with-param name="plural" select="'Vehicle Journeys'"/>
				</xsl:call-template>
			</itemizedlist>
			<xsl:apply-templates select="txc:Registrations/txc:Registration" mode="documentSummary"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:VosaRegistrationNumber">
		<xsl:value-of select="concat(txc:TanCode, txc:LicenceNumber, '/', txc:RegistrationNumber)"/>
	</xsl:template>
	<xsl:template match="txc:Registration" mode="documentSummary">
		<informaltable>
			<tgroup cols="2">
				<colspec colwidth="1*"/>
				<colspec colwidth="2*"/>
				<tbody>
					<xsl:call-template name="tableRow">
						<xsl:with-param name="label" select="'Registration Reference'"/>
						<xsl:with-param name="value" select="txc:VosaRegistrationNumber"/>
					</xsl:call-template>
					<xsl:call-template name="tableRow">
						<xsl:with-param name="label" select="'Submission Date'"/>
						<xsl:with-param name="value" select="txc:SubmissionDate"/>
					</xsl:call-template>
					<xsl:call-template name="tableRow">
						<xsl:with-param name="label" select="'Traffic Areas'"/>
						<xsl:with-param name="value" select="txc:TrafficAreas"/>
					</xsl:call-template>
					<xsl:variable name="serviceCode" select="txc:ServiceRef"/>
					<xsl:variable name="operatorCode" select="//txc:TransXChange/txc:Services/txc:Service[txc:ServiceCode=$serviceCode]/txc:RegisteredOperatorRef"/>
					<xsl:call-template name="tableRow">
						<xsl:with-param name="label" select="'Registered Operator'"/>
						<xsl:with-param name="value" select="//txc:TransXChange/txc:Operators/txc:LicensedOperator[@id=$operatorCode]/txc:OperatorNameOnLicence"/>
					</xsl:call-template>
					<xsl:call-template name="tableRow">
						<xsl:with-param name="label" select="'Lines'"/>
						<xsl:with-param name="value" select="//txc:TransXChange/txc:Services/txc:Service[txc:ServiceCode=$serviceCode]/txc:Lines"/>
					</xsl:call-template>
				</tbody>
			</tgroup>
		</informaltable>
	</xsl:template>
	<xsl:template match="txc:Operators">
		<section>
			<title>Operators</title>
			<xsl:apply-templates select="txc:LicensedOperator|txc:Operator"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:LicensedOperator|txc:Operator">
		<section>
			<title>
				<xsl:value-of select="txc:OperatorShortName"/>
			</title>
			<xsl:call-template name="standardAttributes">
				<xsl:with-param name="parentElement" select="."/>
			</xsl:call-template>
			<informaltable>
				<tgroup cols="2">
					<colspec colwidth="1*"/>
					<colspec colwidth="2*"/>
					<tbody>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'National Operator Code'"/>
							<xsl:with-param name="value" select="txc:NationalOperatorCode"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:if test="$mode='full'">
							<xsl:call-template name="tableRow">
								<xsl:with-param name="label" select="'Operator Code'"/>
								<xsl:with-param name="value" select="txc:OperatorCode"/>
								<xsl:with-param name="omitIfBlank" select="true()"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Name on Licence'"/>
							<xsl:with-param name="value" select="txc:OperatorNameOnLicence"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Trading Name'"/>
							<xsl:with-param name="value" select="txc:TradingName"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Correspondence Address'"/>
							<xsl:with-param name="value" select="txc:OperatorAddresses/txc:CorrespondenceAddress"/>
						</xsl:call-template>
						<xsl:if test="$mode='full'">
							<xsl:call-template name="tableRow">
								<xsl:with-param name="label" select="'Alternative Addresses'"/>
								<xsl:with-param name="value" select="txc:OperatorAddresses/txc:MiscellaneousAddress"/>
								<xsl:with-param name="omitIfBlank" select="true()"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Contact Number'"/>
							<xsl:with-param name="value" select="txc:ContactTelephoneNumber"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Enquiry Number'"/>
							<xsl:with-param name="value" select="txc:EnquiryTelephoneNumber"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Email'"/>
							<xsl:with-param name="value" select="txc:EmailAddress"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Licence Number'"/>
							<xsl:with-param name="value" select="txc:LicenceNumber"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Licence Type'"/>
							<xsl:with-param name="value" select="txc:LicenceClassification"/>
						</xsl:call-template>
					</tbody>
				</tgroup>
			</informaltable>
		</section>
	</xsl:template>
	<xsl:template match="txc:CorrespondenceAddress|txc:MiscellaneousAddress">
		<literallayout>
			<xsl:for-each select="apd:Line">
				<xsl:value-of select="."/>
				<xsl:text>&#xa;</xsl:text>
			</xsl:for-each>
			<xsl:value-of select="apd:PostCode"/>
			<xsl:text>&#xa;</xsl:text>
		</literallayout>
	</xsl:template>
	<xsl:template match="txc:Phone|txc:ContactTelephoneNumber|txc:EnquiryTelephoneNumber">
		<xsl:if test="txc:TelCountryCode">
			(+<xsl:value-of select="txc:TelCountryCode"/>
			<xsl:text> </xsl:text>)
		</xsl:if>
		<xsl:value-of select="txc:TelNationalNumber"/>
		<xsl:if test="txc:TelExtensionNumber">
			<xsl:text> </xsl:text>
			<xsl:value-of select="txc:TelExtensionNumber"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="txc:EmailAddress|txc:Email">
		<email>
			<xsl:value-of select="."/>
		</email>
	</xsl:template>
	<xsl:template match="txc:LicenceClassification">
		<xsl:choose>
			<xsl:when test=". = 'standardNational'">Standard National</xsl:when>
			<xsl:when test=". = 'standardInternational'">Standard International</xsl:when>
			<xsl:when test=". = 'restricted'">Restricted</xsl:when>
			<xsl:when test=". = 'specialRestricted'">Special Restricted</xsl:when>
			<xsl:when test=". = 'communityBusPermit'">Community Bus Permit</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ***************************** Service ********************************** -->
	<xsl:template match="txc:Services">
		<section>
			<title>Services</title>
			<xsl:apply-templates select="txc:Service"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:Service">
		<section>
			<title>
				<xsl:if test="count(txc:FlexibleService) = 1">Flexible </xsl:if>Service <xsl:value-of select="txc:ServiceCode"/>
				<xsl:variable name="serviceRef" select="txc:ServiceCode"/>
				<xsl:if test="count(//txc:TransXChange/txc:Registrations/txc:Registration	[txc:ServiceRef=$serviceRef]/txc:VosaRegistrationNumber) = 1">
		        for Registration <xsl:apply-templates select="//txc:TransXChange/txc:Registrations/txc:Registration		[txc:ServiceRef=$serviceRef]/txc:VosaRegistrationNumber"/>
				</xsl:if>
			</title>
			<xsl:call-template name="standardAttributes">
				<xsl:with-param name="parentElement" select="."/>
			</xsl:call-template>
			<informaltable>
				<tgroup cols="2">
					<colspec colwidth="1*"/>
					<colspec colwidth="2*"/>
					<tbody>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Publicly known as'"/>
							<xsl:with-param name="value" select="txc:Lines"/>
						</xsl:call-template>
						<xsl:variable name="registeredOperatorCode" select="txc:RegisteredOperatorRef"/>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Registered for'"/>
							<xsl:with-param name="value" select="//txc:TransXChange/txc:Operators/txc:LicensedOperator[@id=$registeredOperatorCode]/txc:OperatorShortName|//txc:TransXChange/txc:Operators/txc:Operator[@id=$registeredOperatorCode]/txc:OperatorShortName"/>
						</xsl:call-template>
						<xsl:if test="txc:AssociatedOperators">
							<row>
								<entry>Associated operators</entry>
								<entry>
									<emphasis role="bold">
										<xsl:for-each select="txc:AssociatedOperators">
											<xsl:variable name="associatedOperatorCode" select="txc:OperatorRef"/>
											<xsl:value-of select="//txc:TransXChange/txc:Operators/txc:LicensedOperator[@id=$associatedOperatorCode]/txc:OperatorShortName|//txc:TransXChange/txc:Operators/txc:Operator[@id=$associatedOperatorCode]/txc:OperatorShortName"/>
											<xsl:if test="txc:Role">
												<xsl:text> (</xsl:text>
												<xsl:call-template name="toCommaSeparatedList">
													<xsl:with-param name="list" select="txc:Role"/>
												</xsl:call-template>
												<xsl:text>)</xsl:text>
											</xsl:if>
										</xsl:for-each>
									</emphasis>
								</entry>
							</row>
						</xsl:if>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Origin'"/>
							<xsl:with-param name="value" select="txc:StandardService/txc:Origin"/>
							<xsl:with-param name="omitIfBlank" select="count(txc:FlexibleService) = 1"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Destination'"/>
							<xsl:with-param name="value" select="txc:StandardService/txc:Destination"/>
							<xsl:with-param name="omitIfBlank" select="count(txc:FlexibleService) = 1"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Main Points'"/>
							<xsl:with-param name="value" select="txc:StandardService/txc:Vias"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Operating period'"/>
							<xsl:with-param name="value" select="txc:OperatingPeriod"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Classified as'"/>
							<xsl:with-param name="value" select="txc:ServiceClassification"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Description of service'"/>
							<xsl:with-param name="value" select="txc:Description"/>
						</xsl:call-template>
					</tbody>
				</tgroup>
			</informaltable>
		</section>
		<section>
			<title>Further Information</title>
			<informaltable>
				<tgroup cols="2">
					<colspec colwidth="1*"/>
					<colspec colwidth="2*"/>
					<tbody>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Uses all stops'"/>
							<xsl:with-param name="value" select="txc:StandardService/txc:UseAllStopPoints"/>
							<xsl:with-param name="omitIfBlank" select="count(txc:FlexibleService) = 1"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'New stops'"/>
							<xsl:with-param name="value" select="txc:StopRequirements"/>
						</xsl:call-template>
						<row>
							<entry>No fixed stopping places</entry>
							<entry>
								<emphasis role="bold">
									<xsl:choose>
										<xsl:when test="txc:FlexibleService and not(txc:FlexibleService/txc:FlexibleJourneyPattern/txc:FixedStopPoints)">Yes</xsl:when>
										<xsl:otherwise>No</xsl:otherwise>
									</xsl:choose>
								</emphasis>
							</entry>
						</row>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Available for Public Use'"/>
							<xsl:with-param name="value" select="txc:PublicUse"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:if test="txc:Mode and txc:Mode != 'bus'">
							<row>
								<entry>Mode</entry>
								<entry>
									<emphasis role="bold">
										<xsl:value-of select="txc:Mode"/>
									</emphasis>
								</entry>
							</row>
						</xsl:if>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Related services'"/>
							<xsl:with-param name="value" select="txc:ToBeMarketedWith"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
					</tbody>
				</tgroup>
			</informaltable>
		</section>
	</xsl:template>
	<xsl:template match="txc:Lines">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:Line/txc:LineName"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:Vias">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:Via"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:OperatingPeriod">
		<xsl:choose>
			<xsl:when test="txc:EndDate">
				From <xsl:apply-templates select="txc:StartDate"/> to <xsl:apply-templates select="txc:EndDate"/>
			</xsl:when>
			<xsl:otherwise>
				From <xsl:apply-templates select="txc:StartDate"/> (indefinitely)
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:StartDate">
		<xsl:call-template name="formatDate">
			<xsl:with-param name="DateToBeConverted" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:EndDate">
		<xsl:call-template name="formatDate">
			<xsl:with-param name="DateToBeConverted" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:ServiceClassification">
		<xsl:for-each select="*">
			<xsl:choose>
				<xsl:when test="local-name(.) = 'NormalStopping'">Normal Stopping</xsl:when>
				<xsl:when test="local-name(.) = 'LimitedStops'">Limited Stops</xsl:when>
				<xsl:when test="local-name(.) = 'HailAndRide'">Hail and Ride</xsl:when>
				<xsl:when test="local-name(.) = 'Flexible'">Flexible</xsl:when>
				<xsl:when test="local-name(.) = 'ExcursionOrTour'">Excursion Or Tour (Max daily departures: <xsl:value-of select="txc:MaxDepartures"/>)</xsl:when>
				<xsl:when test="local-name(.) = 'SchoolOrWorks'">School or Works</xsl:when>
				<xsl:when test="local-name(.) = 'RuralService'">Rural Service</xsl:when>
				<xsl:when test="local-name(.) = 'OtherService'">Other Service (<xsl:value-of select="txc:Description"/>)</xsl:when>
			</xsl:choose>
			<xsl:if test="position() != last()">
				<xsl:text>, </xsl:text>
			</xsl:if>
		</xsl:for-each>
		<xsl:if test="count(*)=0">
		  Not specified
		</xsl:if>
	</xsl:template>
	<xsl:template match="txc:UseAllStopPoints">
		<xsl:call-template name="formatBoolean">
			<xsl:with-param name="value" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:StopRequirements">
		<xsl:choose>
			<xsl:when test="txc:NoNewStopsRequired">
                    None required.
                  </xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="toCommaSeparatedList">
					<xsl:with-param name="list" select="txc:NewStops/*"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:PublicUse">
		<xsl:call-template name="formatBoolean">
			<xsl:with-param name="value" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:ToBeMarketedWith">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:RelatedService"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:RelatedService">
		<xsl:choose>
			<xsl:when test="txc:ServiceRef">
				<xsl:value-of select="txc:ServiceRef"/>
        (<xsl:value-of select="txc:Description"/>)
      </xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="txc:Description"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ***************************** Registration ********************************** -->
	<xsl:template match="txc:Registrations">
		<section>
			<title>Registrations</title>
			<xsl:apply-templates select="txc:Registration"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:Registration">
		<section>
			<title>
        Registration <xsl:apply-templates select="txc:VosaRegistrationNumber"/>
			</title>
			<xsl:call-template name="standardAttributes">
				<xsl:with-param name="parentElement" select="."/>
			</xsl:call-template>
			<informaltable>
				<tgroup cols="2">
					<colspec colwidth="1*"/>
					<colspec colwidth="2*"/>
					<tbody>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Application Type'"/>
							<xsl:with-param name="value" select="txc:ApplicationClassification"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Traffic Areas'"/>
							<xsl:with-param name="value" select="txc:TrafficAreas"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Circulated Authorities'"/>
							<xsl:with-param name="value" select="txc:CirculatedAuthorities"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Subsidy'"/>
							<xsl:with-param name="value" select="txc:SubsidyDetails"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Subsidising Authorities'"/>
							<xsl:with-param name="value" select="txc:SubsidyDetails/txc:Subsidy"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Variation Number'"/>
							<xsl:with-param name="value" select="txc:VariationNumber"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Contracted Service'"/>
							<xsl:with-param name="value" select="txc:ContractedService"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:if test="txc:ContractedService/txc:ContractingAuthority">
							<row>
								<entry>Contracting Authorities</entry>
								<entry>
									<emphasis role="bold">
										<xsl:call-template name="toCommaSeparatedList">
											<xsl:with-param name="list" select="txc:ContractedService/txc:ContractingAuthority"/>
										</xsl:call-template>
									</emphasis>
								</entry>
							</row>
						</xsl:if>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Quality Partnership'"/>
							<xsl:with-param name="value" select="txc:QualityPartnership"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Submitted by'"/>
							<xsl:with-param name="value" select="txc:SubmissionAuthor"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Position'"/>
							<xsl:with-param name="value" select="txc:SubmissionAuthor/txc:Position"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Supporting Documents'"/>
							<xsl:with-param name="value" select="txc:SupportingDocuments"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
					</tbody>
				</tgroup>
			</informaltable>
			<xsl:if test="txc:ShortNoticeRegistration">
				<section>
					<title>Short Notice Registration</title>
					<section>
						<title>Impact</title>
						<informaltable>
							<tgroup cols="2">
								<colspec colwidth="1*"/>
								<colspec colwidth="2*"/>
								<tbody>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Public Availability'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:PublicAvailability"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Change Limits Exceeded'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:ChangeImpact"/>
									</xsl:call-template>
								</tbody>
							</tgroup>
						</informaltable>
					</section>
					<section>
						<title>Justification</title>
						<informaltable>
							<tgroup cols="2">
								<colspec colwidth="1*"/>
								<colspec colwidth="2*"/>
								<tbody>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Bank Holiday Change'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:BankHolidayChange"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Local Holiday Change'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:LocalHolidayChange/txc:LocalHolidayNote"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Special Occasion Change'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:SpecialOccasion/txc:SpecialOccasionName"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Change to Enable Connecting Service'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:ChangeToConnectAlteredService"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Replace Discontinued Service'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:ReplaceDiscontinuedService"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Change Requested by External Authority'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:ChangeRequestedByExternalAuthority/txc:ChangeRequestDescription "/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Change to meet Regulation Order'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:RegulationOrderCompliance/txc:TrafficOrderNote"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Change to meet Exceptional requirement'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:ExceptionalRequirement/txc:ChangeRequestDescription"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
									<xsl:call-template name="tableRow">
										<xsl:with-param name="label" select="'Miscellaneous Change'"/>
										<xsl:with-param name="value" select="txc:ShortNoticeRegistration/txc:MiscellaneousJustification"/>
										<xsl:with-param name="omitIfBlank" select="true()"/>
									</xsl:call-template>
								</tbody>
							</tgroup>
						</informaltable>
					</section>
				</section>
			</xsl:if>
		</section>
	</xsl:template>
	<xsl:template match="txc:ApplicationClassification">
		<xsl:choose>
			<xsl:when test=". = 'new'">New</xsl:when>
			<xsl:when test=". = 'chargeableChange'">Chargeable Change</xsl:when>
			<xsl:when test=". = 'nonChargeableChange'">Non-chargeable Change</xsl:when>
			<xsl:when test=". = 'cancel'">Cancel</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:TrafficAreas">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:TrafficArea/txc:TrafficAreaName"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:CirculatedAuthorities">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:CirculatedAuthority/txc:AuthorityName"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:SubmissionDate">
		<xsl:call-template name="formatDate">
			<xsl:with-param name="DateToBeConverted" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:SubsidyDetails">
		<xsl:choose>
			<xsl:when test="txc:NoSubsidy">No Subsidy</xsl:when>
			<xsl:when test="txc:Subsidy/txc:SubsidyType='partial'">Partial</xsl:when>
			<xsl:when test="txc:Subsidy/txc:SubsidyType='full'">Full</xsl:when>
			<xsl:otherwise>Unknown</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:Subsidy">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:SubsidisingAuthority"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:ContractedService">
		<xsl:choose>
			<xsl:when test="txc:NotContracted">Not Contracted</xsl:when>
			<xsl:when test="txc:WhollyContracted">Wholly Contracted</xsl:when>
			<xsl:when test="txc:PartContracted">Partly Contracted</xsl:when>
			<xsl:otherwise>Unknown</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:SubmissionAuthor">
		<xsl:value-of select="txc:Title"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="txc:Forename"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="txc:Surname"/>
	</xsl:template>
	<xsl:template match="txc:SupportingDocuments">
		<xsl:call-template name="toCommaSeparatedList">
			<xsl:with-param name="list" select="txc:SupportingDocument/txc:DocumentUri"/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:ShortNoticeRegistration/txc:PublicAvailability">
		<xsl:choose>
			<xsl:when test="txc:AvailableToPublic">Yes</xsl:when>
			<xsl:when test="txc:NotAvailableToPublic">
				<xsl:text>No. </xsl:text>
				<xsl:value-of select="txc:NotAvailableToPublic/txc:NonAvailabilityDescription"/>
			</xsl:when>
			<xsl:otherwise>Unknown</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:ShortNoticeRegistration/txc:ChangeImpact">
		<xsl:choose>
			<xsl:when test="txc:ChangeExceedsLimit">Yes</xsl:when>
			<xsl:when test="txc:ChangeDoesNotExceedLimit">
				<xsl:text>No. </xsl:text>
				<xsl:value-of select="txc:ChangeDoesNotExceedLimit/txc:MinorChangeDescription"/>
			</xsl:when>
			<xsl:otherwise>Unknown</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:ShortNoticeRegistration/txc:BankHolidayChange">
		<xsl:call-template name="formatBoolean">
			<xsl:with-param name="value" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:ShortNoticeRegistration/txc:ChangeToConnectAlteredService">
		<xsl:if test="txc:AlteredServiceRequiringConnection/txc:ServiceRef">
			<xsl:text>Service: </xsl:text>
			<xsl:value-of select="txc:AlteredServiceRequiringConnection/txc:ServiceRef"/>
			<xsl:text>. </xsl:text>
		</xsl:if>
		<xsl:value-of select="txc:AlteredServiceRequiringConnection/txc:Description"/>
	</xsl:template>
	<xsl:template match="txc:ShortNoticeRegistration/txc:ReplaceDiscontinuedService">
		<xsl:if test="txc:DiscontinuedServiceOperator">
			<xsl:text>Operator: </xsl:text>
			<xsl:value-of select="txc:DiscontinuedServiceOperator"/>
			<xsl:text>. </xsl:text>
		</xsl:if>
		<xsl:if test="txc:DiscontinuedService/txc:ServiceRef">
			<xsl:text>Service: </xsl:text>
			<xsl:value-of select="txc:DiscontinuedService/txc:ServiceRef"/>
			<xsl:text>. </xsl:text>
		</xsl:if>
		<xsl:value-of select="txc:DiscontinuedService/txc:Description"/>
	</xsl:template>
	<!-- ***************************** Routes and stops ********************************** -->
	<xsl:template match="txc:StopPoints">
		<section>
			<title>Stopping Points</title>
			<xsl:if test="txc:StopPoint">
				<section>
					<title>Stops Defined in this Document</title>
					<informaltable>
						<tgroup cols="5">
							<colspec colwidth="1*"/>
							<colspec colwidth="2*"/>
							<colspec colwidth="1*"/>
							<colspec colwidth="1*"/>
							<colspec colwidth="2*"/>
							<thead>
								<row>
									<entry>ATCO Code</entry>
									<entry>Name</entry>
									<entry>Stop Type</entry>
									<entry>NPTG Locality Ref</entry>
									<entry>Street</entry>
								</row>
							</thead>
							<tbody>
								<xsl:apply-templates select="txc:StopPoint"/>
							</tbody>
						</tgroup>
					</informaltable>
				</section>
			</xsl:if>
			<xsl:if test="txc:AnnotatedStopPointRef">
				<section>
					<title>Existing Stops Used</title>
					<informaltable>
						<tgroup cols="4">
							<colspec colwidth="1*"/>
							<colspec colwidth="2*"/>
							<colspec colwidth="1*"/>
							<colspec colwidth="2*"/>
							<thead>
								<row>
									<entry>ATCO Code</entry>
									<entry>Name</entry>
									<entry>Stop Type</entry>
									<entry>NPTG Locality</entry>
								</row>
							</thead>
							<tbody>
								<xsl:apply-templates select="txc:AnnotatedStopPointRef"/>
							</tbody>
						</tgroup>
					</informaltable>
				</section>
			</xsl:if>
			<xsl:if test="$mode='full' and count(/txc:TransXChange/txc:StopAreas) = 1">
				<section>
					<title>Stop Areas</title>
					<informaltable>
						<tgroup cols="3">
							<colspec colwidth="1*"/>
							<colspec colwidth="2*"/>
							<colspec colwidth="1*"/>
							<thead>
								<row>
									<entry>ATCO Code</entry>
									<entry>Name</entry>
									<entry>Area Type</entry>
								</row>
							</thead>
							<tbody>
								<xsl:apply-templates select="/txc:TransXChange/txc:StopAreas/txc:StopArea"/>
							</tbody>
						</tgroup>
					</informaltable>
				</section>
			</xsl:if>
		</section>
	</xsl:template>
	<xsl:template match="txc:StopPoint">
		<row>
			<entry>
				<xsl:value-of select="txc:AtcoCode"/>
			</entry>
			<entry>
				<xsl:if test="txc:Descriptor/txc:Indicator">
					<xsl:value-of select="txc:Descriptor/txc:Indicator"/>
					<xsl:text> </xsl:text>
				</xsl:if>
				<xsl:value-of select="txc:Descriptor/txc:CommonName"/>
			</entry>
			<entry>
				<xsl:value-of select="txc:StopClassification/txc:StopType"/>
			</entry>
			<entry>
				<xsl:value-of select="txc:Place/txc:NptgLocalityRef"/>
			</entry>
			<entry>
				<xsl:value-of select="txc:Descriptor/txc:Street"/>
			</entry>
		</row>
	</xsl:template>
	<xsl:template match="txc:AnnotatedStopPointRef">
		<row>
			<entry>
				<xsl:value-of select="txc:StopPointRef"/>
			</entry>
			<entry>
				<xsl:if test="txc:Indicator">
					<xsl:value-of select="txc:Indicator"/>
					<xsl:text> </xsl:text>
				</xsl:if>
				<xsl:value-of select="txc:CommonName"/>
			</entry>
			<entry>
			</entry>
			<entry>
				<xsl:value-of select="txc:LocalityName"/>
				<xsl:if test="txc:LocalityQualifier">
					<xsl:text> (</xsl:text>
					<xsl:value-of select="txc:LocalityQualifier"/>
					<xsl:text>)</xsl:text>
				</xsl:if>
			</entry>
		</row>
	</xsl:template>
	<xsl:template match="txc:StopArea">
		<row>
			<entry>
				<xsl:value-of select="txc:StopAreaCode"/>
			</entry>
			<entry>
				<xsl:value-of select="txc:Name"/>
			</entry>
			<entry>
				<xsl:value-of select="txc:StopAreaType"/>
			</entry>
		</row>
	</xsl:template>
	<xsl:template match="txc:Routes">
		<section>
			<title>Fixed Routes</title>
			<xsl:apply-templates select="txc:Route"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:Route">
		<section>
			<title>
				<xsl:choose>
					<xsl:when test="txc:Description">
						<xsl:value-of select="txc:Description"/>
					</xsl:when>
					<xsl:when test="txc:ReversingManoeuvres">Route Details</xsl:when>
				</xsl:choose>
			</title>
			<xsl:call-template name="standardAttributes">
				<xsl:with-param name="parentElement" select="."/>
			</xsl:call-template>
			<xsl:if test="txc:ReversingManoeuvres">
				<informaltable>
					<tgroup cols="2">
						<colspec colwidth="1*"/>
						<colspec colwidth="2*"/>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Manoeuvres'"/>
							<xsl:with-param name="value" select="txc:ReversingManoeuvres"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
					</tgroup>
				</informaltable>
			</xsl:if>
			<para/>
		</section>
	</xsl:template>
	<xsl:template match="txc:FlexibleService">
		<section>
			<title>Flexible Routes</title>
			<xsl:apply-templates select="txc:FlexibleJourneyPattern"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:FlexibleJourneyPattern">
		<section>
			<title>Route Details<xsl:if test="txc:Description">
					<xsl:text> for Route </xsl:text>
					<xsl:value-of select="txc:Description"/>
				</xsl:if>
			</title>
			<xsl:call-template name="standardAttributes">
				<xsl:with-param name="parentElement" select="."/>
			</xsl:call-template>
			<xsl:apply-templates select="txc:FlexibleZones"/>
			<xsl:apply-templates select="txc:FixedStopPoints"/>
			<xsl:apply-templates select="txc:BookingArrangements"/>
		</section>
	</xsl:template>
	<xsl:template match="txc:FlexibleZones">
		<section>
			<title>Flexible Stops</title>
			<informaltable>
				<tgroup cols="2">
					<thead>
						<row>
							<entry>ATCO Code</entry>
							<entry>Activity</entry>
						</row>
					</thead>
					<tbody>
						<xsl:apply-templates select="txc:FlexibleStopUsage"/>
					</tbody>
				</tgroup>
			</informaltable>
		</section>
	</xsl:template>
	<xsl:template match="txc:FixedStopPoints">
		<section>
			<title>Fixed Stops</title>
			<informaltable>
				<tgroup cols="2">
					<thead>
						<row>
							<entry>ATCO Code</entry>
							<entry>Activity</entry>
						</row>
					</thead>
					<tbody>
						<xsl:apply-templates select="txc:FixedStopUsage"/>
					</tbody>
				</tgroup>
			</informaltable>
		</section>
	</xsl:template>
	<xsl:template match="txc:FlexibleStopUsage|txc:FixedStopUsage">
		<row>
			<entry>
				<xsl:value-of select="txc:StopPointRef"/>
			</entry>
			<entry>
				<xsl:choose>
					<xsl:when test="txc:Activity">
						<xsl:apply-templates select="txc:Activity"/>
					</xsl:when>
					<xsl:otherwise>Pick Up and Set Down</xsl:otherwise>
				</xsl:choose>
			</entry>
		</row>
	</xsl:template>
	<xsl:template match="txc:Activity">
		<xsl:choose>
			<xsl:when test=". = 'pickUp'">Pick Up</xsl:when>
			<xsl:when test=". = 'setDown'">Set Down</xsl:when>
			<xsl:when test=". = 'pickUpAndSetDown'">Pick Up and Set Down</xsl:when>
			<xsl:when test=". = 'pass'">Pass</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="txc:BookingArrangements">
		<section>
			<title>Booking Arrangements</title>
			<informaltable>
				<tgroup cols="2">
					<colspec colwidth="1*"/>
					<colspec colwidth="2*"/>
					<tbody>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Arrangements'"/>
							<xsl:with-param name="value" select="txc:Description"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Phone'"/>
							<xsl:with-param name="value" select="txc:Phone"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Email'"/>
							<xsl:with-param name="value" select="txc:Email"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Address'"/>
							<xsl:with-param name="value" select="txc:Address"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'Web'"/>
							<xsl:with-param name="value" select="txc:WebAddress"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
						<xsl:call-template name="tableRow">
							<xsl:with-param name="label" select="'All Bookings Taken'"/>
							<xsl:with-param name="value" select="txc:AllBookingsTaken"/>
							<xsl:with-param name="omitIfBlank" select="true()"/>
						</xsl:call-template>
					</tbody>
				</tgroup>
			</informaltable>
		</section>
	</xsl:template>
	<xsl:template match="txc:AllBookingsTaken">
		<xsl:call-template name="formatBoolean">
			<xsl:with-param name="value" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="txc:SchematicMap">
		<mediaobject>
			<imageobject>
				<xsl:element name="imagedata">
					<xsl:attribute name="fileref"><xsl:value-of select="$documentBaseDirectory"/><xsl:value-of select="."/></xsl:attribute>
				</xsl:element>
			</imageobject>
		</mediaobject>
	</xsl:template>
	<!-- ***************************** Utilities ********************************** -->
	<xsl:template name="standardAttributes">
		<xsl:param name="parentElement"/>
		<xsl:if test="$parentElement/@CreationDateTime or $parentElement/@RevisionNumber or $parentElement/@ModificationDateTime or $parentElement/@Modification or $parentElement/@Status">
			<informaltable>
				<tgroup cols="4">
					<tbody>
						<row>
							<entry>Creation Date</entry>
							<entry>
								<emphasis role="bold">
									<xsl:choose>
										<xsl:when test="$parentElement/@CreationDateTime">
											<xsl:call-template name="formatDate">
												<xsl:with-param name="DateToBeConverted" select="$parentElement/@CreationDateTime"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>Not specified</xsl:otherwise>
									</xsl:choose>
								</emphasis>
							</entry>
							<entry>Revision Number</entry>
							<entry>
								<emphasis role="bold">
									<xsl:choose>
										<xsl:when test="$parentElement/@RevisionNumber">
											<xsl:value-of select="$parentElement/@RevisionNumber"/>
										</xsl:when>
										<xsl:otherwise>Not specified</xsl:otherwise>
									</xsl:choose>
								</emphasis>
							</entry>
						</row>
						<row>
							<entry>Modification Date</entry>
							<entry>
								<emphasis role="bold">
									<xsl:choose>
										<xsl:when test="$parentElement/@ModificationDateTime">
											<xsl:call-template name="formatDate">
												<xsl:with-param name="DateToBeConverted" select="$parentElement/@ModificationDateTime"/>
											</xsl:call-template>
										</xsl:when>
										<xsl:otherwise>Not specified</xsl:otherwise>
									</xsl:choose>
									<xsl:choose>
										<xsl:when test="$parentElement/@Modification">
		          (<xsl:value-of select="$parentElement/@Modification"/>)
		        </xsl:when>
										<xsl:when test="$parentElement/@ModificationDateTime">
										(new)
									</xsl:when>
									</xsl:choose>
								</emphasis>
							</entry>
							<entry>Status</entry>
							<entry>
								<emphasis role="bold">
									<xsl:choose>
										<xsl:when test="$parentElement/@Status">
											<xsl:value-of select="$parentElement/@Status"/>
										</xsl:when>
										<xsl:otherwise>active</xsl:otherwise>
									</xsl:choose>
								</emphasis>
							</entry>
						</row>
					</tbody>
				</tgroup>
			</informaltable>
		</xsl:if>
	</xsl:template>
	<xsl:template name="tableRow">
		<xsl:param name="label"/>
		<xsl:param name="value"/>
		<xsl:param name="omitIfBlank" select="false()"/>
		<xsl:if test="not($omitIfBlank) or $value">
			<row>
				<entry>
					<xsl:value-of select="$label"/>
				</entry>
				<entry>
					<emphasis role="bold">
						<xsl:apply-templates select="$value"/>
					</emphasis>
				</entry>
			</row>
		</xsl:if>
	</xsl:template>
	<xsl:template name="itemCountListItem">
		<xsl:param name="count"/>
		<xsl:param name="singular"/>
		<xsl:param name="plural"/>
		<xsl:param name="omitIfZero" select="false()"/>
		<xsl:if test="not($omitIfZero) or $count>0">
			<listitem>
				<para>
					<xsl:value-of select="$count"/>
					<xsl:value-of select="' '"/>
					<xsl:call-template name="singularOrPlural">
						<xsl:with-param name="count" select="$count"/>
						<xsl:with-param name="singular" select="$singular"/>
						<xsl:with-param name="plural" select="$plural"/>
					</xsl:call-template>
				</para>
			</listitem>
		</xsl:if>
	</xsl:template>
	<xsl:template name="singularOrPlural">
		<xsl:param name="count"/>
		<xsl:param name="singular"/>
		<xsl:param name="plural"/>
		<xsl:choose>
			<xsl:when test="$count = 1">
				<xsl:value-of select="$singular"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$plural"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="toCommaSeparatedList">
		<xsl:param name="list"/>
		<xsl:for-each select="$list">
			<xsl:value-of select="."/>
			<xsl:if test="position() &lt; last()">
				<xsl:value-of select="', '"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="formatBoolean">
		<xsl:param name="value"/>
		<xsl:choose>
			<xsl:when test="$value = 'true' or $value = 1">
				Yes
			</xsl:when>
			<xsl:otherwise>
				No
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="formatDate">
		<!--  Returns a Human-Readable date from an ISO 8601 Date  -->
		<xsl:param name="DateToBeConverted"/>
		<xsl:variable name="DayNumber" select="substring(string($DateToBeConverted), 9, 2)"/>
		<xsl:variable name="MonthNumber" select="substring(string($DateToBeConverted), 6, 2)"/>
		<xsl:variable name="YearNumber" select="substring(string($DateToBeConverted), 1, 4)"/>
		<xsl:choose>
			<xsl:when test="$DayNumber &lt; 10">
				<xsl:value-of select="substring(string($DayNumber), 2, 1)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$DayNumber"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="$MonthNumber = '01'"> January </xsl:when>
			<xsl:when test="$MonthNumber = '02'"> February </xsl:when>
			<xsl:when test="$MonthNumber = '03'"> March </xsl:when>
			<xsl:when test="$MonthNumber = '04'"> April </xsl:when>
			<xsl:when test="$MonthNumber = '05'"> May </xsl:when>
			<xsl:when test="$MonthNumber = '06'"> June </xsl:when>
			<xsl:when test="$MonthNumber = '07'"> July </xsl:when>
			<xsl:when test="$MonthNumber = '08'"> August </xsl:when>
			<xsl:when test="$MonthNumber = '09'"> September </xsl:when>
			<xsl:when test="$MonthNumber = '10'"> October </xsl:when>
			<xsl:when test="$MonthNumber = '11'"> November </xsl:when>
			<xsl:when test="$MonthNumber = '12'"> December </xsl:when>
		</xsl:choose>
		<xsl:value-of select="$YearNumber"/>
	</xsl:template>
	<!--  Copies atrributes and nodes for included raw DocBook files.  -->
	<xsl:template match="@*|node()" mode="raw-docbook">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()" mode="raw-docbook"/>
		</xsl:copy>
	</xsl:template>
</xsl:stylesheet>
